import { verifySession } from "@/app/_lib/dal";
import { getLinkTypeList, LinkType } from "@/app/_lib/data/linkType";
import { getCollection } from "@/app/_lib/mongodb";
import { ObjectId } from "mongodb";
import { NextRequest } from "next/server";

export async function GET(req: NextRequest) {
    try {
        // 获取分页参数
        const page = parseInt(req.nextUrl.searchParams.get('page') || '1') || 1;
        const pageSize = parseInt(req.nextUrl.searchParams.get('pageSize') || '10') || 10;
        const res = await getLinkTypeList({ page, pageSize })
        return Response.json(res)
    } catch {
        return Response.error()
    }
}
export async function POST(req: NextRequest) {
    try {
        const session = await verifySession()

        // Check if the user is authenticated
        if (!session) {
            // User is not authenticated
            return new Response(null, { status: 401 })
        }
        // 获取待插入的对象
        const link = await req.json()
        const collection = await getCollection('link-type')
        await collection.insertOne(link)
        return Response.json({ message: '成功' })
    } catch  {
        return Response.error()
    }
}

export async function PUT(req: NextRequest) {
    try {
        const session = await verifySession()

        // Check if the user is authenticated
        if (!session) {
            // User is not authenticated
            return new Response(null, { status: 401 })
        }
        // 获取待更新的对象
        const link = await req.json() as LinkType
        const collection = await getCollection('link-type')
        await collection.replaceOne({ _id: new ObjectId(link._id) }, { ...link, _id: new ObjectId(link._id) })
        return Response.json({ message: '成功' })
    } catch (e) {
        console.log(e);

        return Response.error()
    }
}