import { verifySession } from "@/app/_lib/dal";
import { getSearchTypeList, SearchTypeItem } from "@/app/_lib/data/search";
import { getCollection } from "@/app/_lib/mongodb";
import { ObjectId } from "mongodb";
import { NextRequest } from "next/server";

export async function GET(req: NextRequest) {
    try {
        // Check if the user is authenticated

        const page = parseInt(req.nextUrl.searchParams.get('page') || '1') || 1;
        const pageSize = parseInt(req.nextUrl.searchParams.get('pageSize') || '10') || 10;

        const res = await getSearchTypeList({ page, pageSize })
        return Response.json(res)
    } catch  {
        return Response.error()
    }
}
export async function POST(req: NextRequest) {
    try {
        const session = await verifySession()

        // Check if the user is authenticated
        if (!session) {
            // User is not authenticated
            return new Response(null, { status: 401 })
        }
        const collection = await getCollection('search-type')
        const item = await req.json()
        
        const res = collection.insertOne(item)
        return Response.json(res)
    } catch {
        return Response.error()
    }
}

export async function PUT(req: NextRequest) {
    try {
        const session = await verifySession()

        // Check if the user is authenticated
        if (!session) {
            // User is not authenticated
            return new Response(null, { status: 401 })
        }
        // 获取待更新的对象
        const collection = await getCollection('search-type')
        const item = await req.json() as SearchTypeItem
        const res = await collection.replaceOne({ _id: new ObjectId(item._id) }, { ...item, _id: new ObjectId(item._id) })
        return Response.json(res)
    } catch {
        return Response.error()
    }
}